"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const data = [{
        id: 1,
        fname: 'lalalan',
        lname: 'nana',
        created_at: '1990-02-01',
        updated_at: '2000-02-01',
        posts: [{
                topic: 'im cool'
            },
            {
                topic: 'so cool cool'
            }
        ]
    }, {
        id: 2,
        fname: 'bababan',
        lname: 'nana',
        created_at: '1990-02-01',
        updated_at: '2000-02-01'
    }];
const index_1 = require("./index");
class UserCollection {
    constructor(data) {
        return {
            api: "v1",
            meta: {
                next: "---",
                prev: "---"
            },
            data: data
        };
    }
}
class PostResource extends index_1.Resource {
    toArray() {
        return {
            topic: this.topic
        };
    }
}
class UserResource extends index_1.Resource {
    toArray() {
        return {
            id: this.id,
            fname: this.fname,
            lname: this.lname,
            posts: PostResource.collection(this.posts),
            created_at: this.created_at,
            updated_at: this.updated_at,
        };
    }
}
class BlankResource extends index_1.Resource {
}
describe('testing index file', () => {
    test('should transform a collection.', () => {
        const collection = UserResource.collection(data);
        expect(collection).toEqual([
            {
                "id": 1,
                "fname": "lalalan",
                "lname": "nana",
                "posts": [
                    {
                        "topic": "im cool"
                    },
                    {
                        "topic": "so cool cool"
                    }
                ],
                "created_at": "1990-02-01",
                "updated_at": "2000-02-01"
            },
            {
                "id": 2,
                "fname": "bababan",
                "lname": "nana",
                "posts": [],
                "created_at": "1990-02-01",
                "updated_at": "2000-02-01"
            }
        ]);
    });
    test('should transform a single item.', () => {
        const collection = new UserResource(data[0]);
        expect(collection).toEqual({
            "id": 1,
            "fname": "lalalan",
            "lname": "nana",
            "posts": [
                {
                    "topic": "im cool"
                },
                {
                    "topic": "so cool cool"
                }
            ],
            "created_at": "1990-02-01",
            "updated_at": "2000-02-01"
        });
    });
    test('should transform a collection with the data key.', () => {
        const collection = UserResource.collection({ data: data });
        expect(collection).toEqual({
            "data": [
                {
                    "id": 1,
                    "fname": "lalalan",
                    "lname": "nana",
                    "posts": [
                        {
                            "topic": "im cool"
                        },
                        {
                            "topic": "so cool cool"
                        }
                    ],
                    "created_at": "1990-02-01",
                    "updated_at": "2000-02-01"
                },
                {
                    "id": 2,
                    "fname": "bababan",
                    "lname": "nana",
                    "posts": [],
                    "created_at": "1990-02-01",
                    "updated_at": "2000-02-01"
                }
            ]
        });
    });
    test('should transform a collection wrapper.', () => {
        const collection = UserResource.collection(new UserCollection(data));
        expect(collection).toEqual({
            "api": "v1",
            "meta": {
                "next": "---",
                "prev": "---"
            },
            "data": [
                {
                    "id": 1,
                    "fname": "lalalan",
                    "lname": "nana",
                    "posts": [
                        {
                            "topic": "im cool"
                        },
                        {
                            "topic": "so cool cool"
                        }
                    ],
                    "created_at": "1990-02-01",
                    "updated_at": "2000-02-01"
                },
                {
                    "id": 2,
                    "fname": "bababan",
                    "lname": "nana",
                    "posts": [],
                    "created_at": "1990-02-01",
                    "updated_at": "2000-02-01"
                }
            ]
        });
    });
    test('should transform a single item data kay with collection wrapper.', () => {
        const collection = UserResource.collection(new UserCollection([data[1]]));
        expect(collection).toEqual({
            "api": "v1",
            "meta": {
                "next": "---",
                "prev": "---"
            },
            "data": [
                {
                    "id": 2,
                    "fname": "bababan",
                    "lname": "nana",
                    "posts": [],
                    "created_at": "1990-02-01",
                    "updated_at": "2000-02-01"
                }
            ]
        });
    });
    test('should transform a single item without toArray.', () => {
        const collection = new BlankResource(data[0]);
        expect(collection).toEqual({
            "id": 1,
            "fname": "lalalan",
            "lname": "nana",
            "created_at": "1990-02-01",
            "updated_at": "2000-02-01",
            "posts": [
                {
                    "topic": "im cool"
                },
                {
                    "topic": "so cool cool"
                }
            ]
        });
    });
});
//# sourceMappingURL=index.spec.js.map